ActiveActivityUpdate class

Class to represent an active activity update

Inheritance

Constructors

ActiveActivityUpdate({required String activityId, required String activityToken})
Constructor for an active activity update

Properties

activityId → String
The id of the activity
finalinherited
activityToken → String
The token of the activity
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult active(ActiveActivityUpdate value), required TResult ended(EndedActivityUpdate value), required TResult stale(StaleActivityUpdate value), required TResult unknown(UnknownActivityUpdate value)}) → TResult
Map the activity update to a specific type
override
mapOrNull<TResult extends Object?>({TResult active(ActiveActivityUpdate value)?, TResult ended(EndedActivityUpdate value)?, TResult stale(StaleActivityUpdate value)?, TResult unknown(UnknownActivityUpdate value)?}) → TResult?
Map the activity update to a specific type or return null
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited