AppGroupsFileService class

Service to handle all processes to files that are sent to the app groups

Constructors

AppGroupsFileService()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

init({required String appGroupId}) → void
Initialize the service with the app group id
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllFiles() → Future<void>
Remove all files from the app group directory
removeFilesSession() → Future<void>
Remove all files that were copied to the app groups in this session
sendFilesToAppGroups(Map<String, dynamic> data) → Future
Send files to the app groups directory
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited